import 'dart:math';

import 'package:flutter/material.dart';
import 'package:flutter_custom_toolbox/flutter_toolbox.dart';

import 'package:petitbac/config/default_activity_settings.dart';
import 'package:petitbac/models/settings/settings_activity.dart';
import 'package:petitbac/models/settings/settings_global.dart';

class ParameterPainter extends CustomPainter {
  const ParameterPainter({
    required this.code,
    required this.value,
    required this.activitySettings,
    required this.globalSettings,
  });

  final String code;
  final String value;
  final ActivitySettings activitySettings;
  final GlobalSettings globalSettings;

  @override
  void paint(Canvas canvas, Size size) {
    // force square
    final double canvasSize = min(size.width, size.height);

    // content
    switch (code) {
      case DefaultActivitySettings.parameterCodeItemsCount:
        paintItemsCountParameterItem(canvas, canvasSize);
        break;
      case DefaultActivitySettings.parameterCodeTimerValue:
        paintTimerParameterItem(canvas, canvasSize);
        break;
      default:
        printlog('Unknown parameter: $code/$value');
        paintUnknownParameterItem(canvas, canvasSize);
    }
  }

  @override
  bool shouldRepaint(CustomPainter oldDelegate) {
    return false;
  }

  // "unknown" parameter -> simple block with text
  void paintUnknownParameterItem(
    final Canvas canvas,
    final double size,
  ) {
    final paint = Paint();
    paint.strokeJoin = StrokeJoin.round;
    paint.strokeWidth = 3;

    final textSpan = TextSpan(
      text: '$code\n$value',
      style: const TextStyle(
        color: Colors.black,
        fontSize: 18,
        fontWeight: FontWeight.bold,
      ),
    );
    final textPainter = TextPainter(
      text: textSpan,
      textDirection: TextDirection.ltr,
      textAlign: TextAlign.center,
    );
    textPainter.layout();
    textPainter.paint(
      canvas,
      Offset(
        (size - textPainter.width) * 0.5,
        (size - textPainter.height) * 0.5,
      ),
    );
  }

  void paintItemsCountParameterItem(
    final Canvas canvas,
    final double size,
  ) {
    const itemCountEmoji = '💬';

    String text =
        '$itemCountEmoji\n${DefaultActivitySettings.getItemsCountValueFromCode(value)}';

    switch (value) {
      case DefaultActivitySettings.itemsCountValueNoLimit:
        text = '⭐';
        break;
      case DefaultActivitySettings.itemsCountValueShort:
        break;
      case DefaultActivitySettings.itemsCountValueMedium:
        break;
      case DefaultActivitySettings.itemsCountValueLong:
        break;
      default:
        printlog('Wrong value for itemsCount parameter value: $value');
    }

    final paint = Paint();
    paint.strokeJoin = StrokeJoin.round;
    paint.strokeWidth = 3 / 100 * size;

    // centered text value
    final textSpan = TextSpan(
      text: text,
      style: TextStyle(
        color: Colors.black,
        fontSize: size / 2.6,
        fontWeight: FontWeight.bold,
      ),
    );
    final textPainter = TextPainter(
      text: textSpan,
      textDirection: TextDirection.ltr,
      textAlign: TextAlign.center,
    );
    textPainter.layout();
    textPainter.paint(
      canvas,
      Offset(
        (size - textPainter.width) * 0.5,
        (size - textPainter.height) * 0.5,
      ),
    );
  }

  void paintTimerParameterItem(
    final Canvas canvas,
    final double size,
  ) {
    const timerEmoji = '⏲️';

    String text = '$timerEmoji\n${DefaultActivitySettings.getTimerValueFromCode(value)}"';

    switch (value) {
      case DefaultActivitySettings.timerValueNoTimer:
        text = '⭐';
        break;
      case DefaultActivitySettings.timerValueLow:
        break;
      case DefaultActivitySettings.timerValueMedium:
        break;
      case DefaultActivitySettings.timerValueHigh:
        break;
      default:
        printlog('Wrong value for itemsCount parameter value: $value');
    }

    final paint = Paint();
    paint.strokeJoin = StrokeJoin.round;
    paint.strokeWidth = 3;

    // centered text value
    final textSpan = TextSpan(
      text: text,
      style: TextStyle(
        color: Colors.black,
        fontSize: size / 2.6,
        fontWeight: FontWeight.bold,
      ),
    );
    final textPainter = TextPainter(
      text: textSpan,
      textDirection: TextDirection.ltr,
      textAlign: TextAlign.center,
    );
    textPainter.layout();
    textPainter.paint(
      canvas,
      Offset(
        (size - textPainter.width) * 0.5,
        (size - textPainter.height) * 0.5,
      ),
    );
  }
}
