import 'package:flutter/material.dart';
import 'package:flutter_custom_toolbox/flutter_toolbox.dart';

import 'package:petitbac/config/default_activity_settings.dart';
import 'package:petitbac/models/settings/settings_activity.dart';

part 'settings_activity_state.dart';

class ActivitySettingsCubit extends HydratedCubit<ActivitySettingsState> {
  ActivitySettingsCubit()
      : super(ActivitySettingsState(settings: ActivitySettings.createDefault()));

  void setValues({
    String? itemsCount,
    String? timerValue,
  }) {
    emit(
      ActivitySettingsState(
        settings: ActivitySettings(
          itemsCount: itemsCount ?? state.settings.itemsCount,
          timerValue: timerValue ?? state.settings.timerValue,
        ),
      ),
    );
  }

  String getParameterValue(String code) {
    switch (code) {
      case DefaultActivitySettings.parameterCodeItemsCount:
        return ActivitySettings.getItemsCountValueFromUnsafe(state.settings.itemsCount);
      case DefaultActivitySettings.parameterCodeTimerValue:
        return ActivitySettings.getTimerValueFromUnsafe(state.settings.timerValue);
    }

    return '';
  }

  void setParameterValue(String code, String value) {
    final String itemsCount = code == DefaultActivitySettings.parameterCodeItemsCount
        ? value
        : getParameterValue(DefaultActivitySettings.parameterCodeItemsCount);
    final String timerValue = code == DefaultActivitySettings.parameterCodeTimerValue
        ? value
        : getParameterValue(DefaultActivitySettings.parameterCodeTimerValue);

    setValues(
      itemsCount: itemsCount,
      timerValue: timerValue,
    );
  }

  @override
  ActivitySettingsState? fromJson(Map<String, dynamic> json) {
    final String itemsCount = json[DefaultActivitySettings.parameterCodeItemsCount] as String;
    final String timerValue = json[DefaultActivitySettings.parameterCodeTimerValue] as String;

    return ActivitySettingsState(
      settings: ActivitySettings(
        itemsCount: itemsCount,
        timerValue: timerValue,
      ),
    );
  }

  @override
  Map<String, dynamic>? toJson(ActivitySettingsState state) {
    return <String, dynamic>{
      DefaultActivitySettings.parameterCodeItemsCount: state.settings.itemsCount,
      DefaultActivitySettings.parameterCodeTimerValue: state.settings.timerValue,
    };
  }
}
