import 'package:flutter_custom_toolbox/flutter_toolbox.dart';

import 'package:petitbac/config/default_activity_settings.dart';

class ActivitySettings {
  final String itemsCount;
  final String timerValue;

  ActivitySettings({
    required this.itemsCount,
    required this.timerValue,
  });

  int get itemsCountValue => DefaultActivitySettings.getItemsCountValueFromCode(itemsCount);
  int get timerCountValue => DefaultActivitySettings.getTimerValueFromCode(timerValue);

  static String getItemsCountValueFromUnsafe(String itemsCount) {
    if (DefaultActivitySettings.allowedItemsCountValues.contains(itemsCount)) {
      return itemsCount;
    }

    return DefaultActivitySettings.defaultItemsCountValue;
  }

  static String getTimerValueFromUnsafe(String timerValue) {
    if (DefaultActivitySettings.allowedTimerValues.contains(timerValue)) {
      return timerValue;
    }

    return DefaultActivitySettings.defaultTimerValue;
  }

  factory ActivitySettings.createDefault() {
    return ActivitySettings(
      itemsCount: DefaultActivitySettings.defaultItemsCountValue,
      timerValue: DefaultActivitySettings.defaultTimerValue,
    );
  }

  void dump() {
    printlog('$ActivitySettings:');
    printlog('  ${DefaultActivitySettings.parameterCodeItemsCount}: $itemsCount');
    printlog('  ${DefaultActivitySettings.parameterCodeTimerValue}: $timerValue');
    printlog('');
  }

  @override
  String toString() {
    return '$ActivitySettings(${toJson()})';
  }

  Map<String, dynamic>? toJson() {
    return <String, dynamic>{
      DefaultActivitySettings.parameterCodeItemsCount: itemsCount,
      DefaultActivitySettings.parameterCodeTimerValue: timerValue,
    };
  }
}
